#
# spec file for package python-django-nose
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-nose
Version:        1.4.6
Release:        bp154.1.29
Summary:        Django test runner that uses python-nose
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://github.com/django-nose/django-nose
Source:         https://files.pythonhosted.org/packages/source/d/django-nose/django-nose-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module dj-database-url}
BuildRequires:  %{python_module nose >= 1.2.1}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-nose >= 1.2.1
BuildArch:      noarch
%python_subpackages

%description
Django test runner that uses nose.

%prep
%setup -q -n django-nose-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec ./manage.py test testapp/tests.py

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst changelog.rst
%{python_sitelib}/*

%changelog
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
* Tue Dec 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.4.6:
  * py3.7 support
  * Django 2.0 and 2.1 support
* Thu Oct  5 2017 toddrme2178@gmail.com
- Change django dependency to proper name Django.
* Wed Aug 23 2017 t.gruner@katodev.de
- add multi-python support
- update to 1.4.5
  * Add Django 1.11 support
* Thu Aug 11 2016 tbechtold@suse.com
- update to 1.4.4:
  * Add Django 1.10 support
  * Drop Django 1.4, 1.7, and Python 2.6 support
  * Drop South support
  * Add Django 1.9 support
  * Support long options without equals signs, such as "--attr selected"
  * Support nose plugins using callback options
  * Support nose options without default values (jsatt)
  * Remove Django from install dependencies, to avoid accidental upgrades
  (jsocol, willkg)
  * Setting REUSE_DB to an empty value now disables REUSE_DB, instead of
  enabling it (wdoekes)
  * Warn against using REUSE_DB=1 and FastFixtureTestCase in docs
  * REUSE_DB=1 uses new transaction management in Django 1.7, 1.8 (scottsexton)
  * Try to avoid accidentally using production database with REUSE_DB=1 (alexjg, eroninjapan)
  * Supported Django versions limited to current supported Django version 1.4,
  1.7, and 1.8, as well as relevant Python versions.
  * Fix version number (ezarowny)
  * Fix choice options, unbreaking nose-cover (aamirtharaj-rpx, jwhitlock)
  * Support 1.8 app loading system (dgladkov)
  * Support non-ASCII file names (singingwolfboy)
  * Better PEP8'd assertion names (roganov)
- Fix Url
- Use pypi.io as Source url
- Adjust Requires
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 1.4:
  * Django 1.8 support (timc3, adepue, jwhitlock)
  * Support --testrunner option (st3lk)
  * Fix REUSE_DB second run in py3k (edrmp)
- additional chanes from version 1.3:
  * Django 1.6 and 1.7 support (conrado, co3k, Nepherhotep,
    mbertheau)
  * Python 3.3 and 3.4 testing and support (frewsxcv, jsocol)
- point the source URL to pypi
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Aug 13 2013 dmueller@suse.com
- update to 1.2:
  * Initial Python 3.x support
* Fri Jun 15 2012 saschpe@suse.de
- Disable testsuite
- Require python-nose
* Mon May 21 2012 alexandre@exatati.com.br
- Update to 1.1:
  * Django TransactionTestCases don't clean up after themselves;
    they leave junk in the DB and clean it up only on _pre_setup.
    Thus, Django makes sure these tests run last. Now django-nose
    does, too. This means one fewer source of failures on existing
    projects. (Erik Rose)
  * Add support for hygienic TransactionTestCases. (Erik Rose)
  * Support models that are used only for tests. Just put them in
    any file imported in the course of loading tests. No more crazy
    hacks necessary. (Erik Rose)
  * Make the fixture bundler more conservative, fixing some conceivable
    situations in which fixtures would not appear as intended if a
    TransactionTestCase found its way into the middle of a bundle.
    (Erik Rose)
  * Fix an error that would surface when using SQLAlchemy with
    connection pooling. (Roger Hu)
  * Gracefully ignore the new --liveserver option introduced in
    Django 1.4; don't let it through to nose. (Adam DePue)
* Fri Mar 23 2012 saschpe@suse.de
- Use upstream tarball
- Simplified macro usage
- Run testsuite
* Wed Mar 14 2012 alexandre@exatati.com.br
- Update to 1.0.0:
  * New fixture-bundling plugin for avoiding needless fixture setup (Erik Rose)
  * Moved FastFixtureTestCase in from test-utils, so now all the
    fixture-bundling stuff is in one library. (Erik Rose)
  * Added the REUSE_DB setting for faster startup and shutdown. (Erik Rose)
  * Fixed a crash when printing options with certain verbosities. (Daniel Abel)
  * Broke hard dependency on MySQL. Support PostgreSQL. (Roger Hu)
  * Support SQLite, both memory- and disk-based. (Roger Hu and Erik Rose)
  * Nail down versions of the package requirements. (Daniel Mizyrycki)
* Wed Dec 28 2011 alexandre@exatati.com.br
- Remove CFLAGS from spec file.
* Fri Nov 25 2011 cfarrell@suse.com
- license update: BSD-3-Clause
  SDPX format
* Thu Nov 24 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack.
* Wed Nov  3 2010 alexandre@exatati.com.br
- Initial package (0.1.3) for openSUSE.
